==> openGion7.2.8.0_dev.zip: uap/webapps/ge/db/FIREBIRD/sql/install/01_TABLE/GE71S.sql <==
/****************************************************************************/
/* GE71 ( 取込実績ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:35                                            */
/****************************************************************************/

CREATE TABLE GE71 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*   1 ｼｽﾃﾑID       */
 , RSRV_NO      INTEGER                             NOT NULL            /*   2 予約番号     */
 , EXECID       VARCHAR (   20 )                    NOT NULL            /*   3 処理ID       */
 , FGTKAN       VARCHAR (    1 )        DEFAULT '2' NOT NULL            /*   4 取込完了ﾌﾗｸﾞ */
 , TMSTR        VARCHAR (   14 )                    NOT NULL            /*   5 開始時刻     */
 , TMEND        VARCHAR (   14 )                                        /*   6 完了時刻     */
 , FILE_IN      VARCHAR (  255 )                                        /*   7 ﾌｧｲﾙ取込     */
 , FILE_OK      VARCHAR (  255 )                                        /*   8 処理済OKﾌｧｲﾙ */
 , FILE_NG      VARCHAR (  255 )                                        /*   9 処理済NGﾌｧｲﾙ */
 , SUTORI       INTEGER                             NOT NULL            /*  10 取込件数     */
 , ERRMSG       VARCHAR ( 4000 )                                        /*  11 ｴﾗｰﾒｯｾｰｼﾞ    */
 , UNIQ         BIGINT                              NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成者       */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者       */
);


CREATE SEQUENCE GE71S00 ;


CREATE TRIGGER GE71T00 FOR GE71
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GE71S00,1 );
  END;

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/FIREBIRD/sql/install/01_TABLE/GE71S.sql <==
/****************************************************************************/
/* GE71 ( 取込実績ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2020/12/16 08:14:13                                            */
/****************************************************************************/

CREATE TABLE GE71 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*   1 ｼｽﾃﾑID       */
 , RSRV_NO      INTEGER                             NOT NULL            /*   2 予約番号     */
 , EXECID       VARCHAR (   20 )                    NOT NULL            /*   3 処理ID       */
 , FGTKAN       VARCHAR (    1 )        DEFAULT '2' NOT NULL            /*   4 取込完了ﾌﾗｸﾞ */
 , TMSTR        VARCHAR (   14 )                    NOT NULL            /*   5 開始時刻     */
 , TMEND        VARCHAR (   14 )                                        /*   6 完了時刻     */
 , FILE_IN      VARCHAR (  255 )                                        /*   7 ﾌｧｲﾙ取込     */
 , FILE_OK      VARCHAR (  255 )                                        /*   8 処理済OKﾌｧｲﾙ */
 , FILE_NG      VARCHAR (  255 )                                        /*   9 処理済NGﾌｧｲﾙ */
 , SUTORI       INTEGER                             NOT NULL            /*  10 取込件数     */
 , ERRMSG       VARCHAR ( 4000 )                                        /*  11 ｴﾗｰﾒｯｾｰｼﾞ    */
 , UNIQ         BIGINT                              NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                        /* 820 作成日時     */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成者       */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者       */
);


CREATE SEQUENCE GE71S00 ;


CREATE TRIGGER GE71T00 FOR GE71
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GE71S00,1 );
  END;
